@@ -8,10 +8,10 @@ class Airtable(InDriver, OutDriver):
     _key = None
     _table = None
 
-    def connect(self, key, table):
+    def connect(self, key, database, table):
         self._key = key
         self._table = table
-        self._airtable = at(key, table)
+        self._airtable = at(base_key=database, table_name=table, api_key=key)
         self.connected = True
         return self
 
@@ -30,9 +30,12 @@ class Airtable(InDriver, OutDriver):
         data = self._airtable.get_all(**kwagrs)
         return self.convert_data_to_df(data)
 
-    def send(self, **kwagrs):
+    def send(self, data):
         self.check_connect()
-        return self._airtable.insert(**kwagrs)
+        if isinstance(data, list):
+            return self._airtable.batch_insert(data)
+        else:
+            return self._airtable.insert(data)
 
     def search(self, **kwagrs):
         self.check_connect()
